/* $Id: xdial.h,v 1.4 1999/11/06 05:50:56 glgay Exp $ */
/*
 Copyright (C) 1996 Peter Williams
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/

#if !defined(_XDIAL_H_)
#define _XDIAL_H_
#include <vector>
#include <Xarm/AppContext.h>
#include <Xarm/Dial.h>
#include <Xarm/Xarm.h>

char *basename(char *);

class DialDemo: public AppContext
{
 private:
   void   onExit(Widget,XtPointer,XtPointer);
   void   onInc(Widget,XtPointer,XtPointer);
   void   exit(Widget,XtPointer,XtPointer);

#if defined(XARM_HAS_NAMESPACES)
   std::vector<Dial *>  dials; 
#else
   vector<Dial *>  dials; 
#endif
   Form           *main_form;
   Label          *label;
   Form           *dial_form;
   RowColumn      *rowcol;
   Scale          *scale;
 
 public:
   DialDemo(char *app_class, int &argc_in_out, char **argv_in_out);
};


#endif 

